Installs Hive on Ubuntu and Fedora.
Hive stores metadata in MySQL databases. So, this element requires 'mysql' element.
You can specify download link for Hive using parameter 'HIVE_DOWNLOAD_URL' or choose Hive version using parameter 'HIVE_VERSION'.
